Changelog
=========

This is an old legacy changelog system, for newer versions, please refer to the changelog associated with github releases.

New version 0.3.0
-----------------

I have split this package in two. This ``geetools`` will contain functions and methods related to Google Earth Engine exclusively, so you can use this module in any python environment you like. For working in Jupyter I have made another package called ``ipygee`` available `here <http://www.github.com/fitoprincipe/ipygee>`__.

New version 0.5.0 (breaking changes)
------------------------------------

I have split this package in two (again). Now the functions to make a strip of images using Pillow is available as a different package called `geepillow <https://github.com/fitoprincipe/geepillow>`__.

New version 0.6.0 (breaking changes)
------------------------------------

I have split this package in two (again x2). The module ``geetools.collection`` in an independent package called `geedataset <https://github.com/fitoprincipe/geedatasets>`__.